/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 32
#define NIM_EmulateOverflowChecks

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg;
typedef struct tySequence__JsYE17s5Dad5mZDxLHKgaw tySequence__JsYE17s5Dad5mZDxLHKgaw;
typedef struct tySequence__6lRdzb9aFAlo79bGaEawph6g tySequence__6lRdzb9aFAlo79bGaEawph6g;
typedef struct tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_Operators__apNm0zcYroUpNRird62c9aQ tyObject_Operators__apNm0zcYroUpNRird62c9aQ;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA;
typedef struct tyTuple__SBroeDF0AeeG8DGttrMudQ tyTuple__SBroeDF0AeeG8DGttrMudQ;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct RootObj RootObj;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct NimStringDesc NimStringDesc;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;

/* section: NIM_merge_TYPES */
struct tyObject_Operators__apNm0zcYroUpNRird62c9aQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opLe;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opLt;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opAnd;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opOr;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opIsNil;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opEq;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opAdd;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opSub;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opMul;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opDiv;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opLen;
};
struct tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q {
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* s;
tyObject_Operators__apNm0zcYroUpNRird62c9aQ o;
NIM_BOOL beSmart;
};
struct tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg {
tySequence__JsYE17s5Dad5mZDxLHKgaw* locals;
tySequence__6lRdzb9aFAlo79bGaEawph6g* slices;
tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q guards;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* args;
NI spawns;
NI currentSpawnId;
NI inLoop;
tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph;
};
struct TGenericSeq {
NI len;
NI reserved;
};
typedef NU8 tyEnum_TDirection__ogNRjad5Q2m49bwMa6pnI3w;
struct tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* alias;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lower;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* upper;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* stride;
tyEnum_TDirection__ogNRjad5Q2m49bwMa6pnI3w dir;
NIM_BOOL blacklisted;
};
struct tyTuple__SBroeDF0AeeG8DGttrMudQ {
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field0;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
NI Field3;
NIM_BOOL Field4;
};
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU8 tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA;
typedef NU16 tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw;
typedef NU64 tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
typedef NimStringDesc* tyArray__yt5VDPNtUGx9cBkOVakHwdQ[6];
typedef NimStringDesc* tyArray__sMpvt1sOxOJ3LFGulnbeMQ[4];
typedef NU8 tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw;
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__JsYE17s5Dad5mZDxLHKgaw {
  TGenericSeq Sup;
  tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA data[SEQ_DECL_SIZE];
};
struct tySequence__6lRdzb9aFAlo79bGaEawph6g {
  TGenericSeq Sup;
  tyTuple__SBroeDF0AeeG8DGttrMudQ data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, initAnalysisCtx__GoSHD4Mq66yV2bANMNqkiA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* Result);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(void, initOperators__3Mq69aIkPINTsOZ4I5g1jZA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_Operators__apNm0zcYroUpNRird62c9aQ* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lastSon__UPSW0jLTX5qJL51YMUAHgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, analyse__PaRoa8NLdkCWN1FglnKPWw)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipConv__BH9abOhPX8pH0DnEWlRxmlw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSingleAssignable__1EjP4hSli31mWSG19b8VOAw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLocal__1EjP4hSli31mWSG19b8VOAw_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA*, getSlot__BqDp9cVNfT8XYSnaRrYoEjg)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v);
N_LIB_PRIVATE N_NIMCALL(NI, lookupSlot__mQQqEPn8XV0sbu4TVfeZfQ)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__JsYE17s5Dad5mZDxLHKgaw)(void* p, NI op);
static N_INLINE(tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA*, X5BX5D___iBfZWB3WtvXDdbJW9aq8zMgsystem)(tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA* s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(void, invalidateFacts__no3iuruVlFxE0wQ8HA9b4ZA)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg, getMagic__4W1ZJaFiusqlhViRx9cbM9bw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* op);
N_LIB_PRIVATE N_NIMCALL(void, gatherArgs__PaRoa8NLdkCWN1FglnKPWw_2)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getRoot__QppXrRxPfamDSGF2rYPMlw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(void, analyseSons__PaRoa8NLdkCWN1FglnKPWw_3)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, addAsgnFact__0CHSuARDyWZ57Xrosqy78w)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* key, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* value);
N_LIB_PRIVATE N_NIMCALL(void, analyseCall__lurTQ8a1NGs6iZ6f4zXjoQ)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* op);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
static N_INLINE(NIM_BOOL, fromSystem__koLUZmQCBRKFmUFVrVvuPQastalgo)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* op);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getModule__xfh8ar7fDxVX2A4OO9b5sqQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, min__hw07ic0yxYJqPZr6HDlP5A)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipStmtList__UPSW0jLTX5qJL51YMUAHgw_4)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, addSlice__bWhVAxARSLxqbiKhEiF3ig)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri);
N_LIB_PRIVATE N_NIMCALL(void, checkLocal__2i9bGbP4MqLVXtqxlsPOB9bg)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, canon__Jdq9bmYnl9bApH9aGfXEZQN8Q_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_Operators__apNm0zcYroUpNRird62c9aQ* o);
N_LIB_PRIVATE N_NIMCALL(void, addLowerBoundAsFacts__oEYSvTAgV5TtcIl6O6tf7A)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c);
N_LIB_PRIVATE N_NIMCALL(void, addFactLe__i9aAoMzJNp9aw6KruJgPZ0Ng)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__I2DV2TmmOysY1ZEGW19b9bRg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(void, checkBounds__jQXLtc0O7sNmd6nxua4Juw)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arr, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* idx);
N_LIB_PRIVATE N_NIMCALL(void, checkLe__UUqGf4gbiwbVS5sZvK0DnQ)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA, proveLe__gquZ4TuLCn9anC5O4OWI4Og)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw renderFlags);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lowBound__Esza4n69a5U9bzlDTK04VArg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, highBound__9cbEq5HLZRHFpEqTjJwMYDA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_Operators__apNm0zcYroUpNRird62c9aQ* o);
static N_NIMCALL(void, Marker_tySequence__6lRdzb9aFAlo79bGaEawph6g)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, genericAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(void, analyseCase__PaRoa8NLdkCWN1FglnKPWw_4)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, addCaseBranchFacts__c6dE6J2nt777cGY9brPJUJA)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI i);
N_LIB_PRIVATE N_NIMCALL(void, analyseIf__PaRoa8NLdkCWN1FglnKPWw_5)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, addFact__ybuIey7mglQLm61kxh9aaLg)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nn);
N_LIB_PRIVATE N_NIMCALL(void, addFactNeg__no3iuruVlFxE0wQ8HA9b4ZA_2)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTrue__9cP6JNeOKqczaXCI4Zo4SBQ_5)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasSubnodeWith__SQs4BrslojahuO1o7NDT4Q)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind);
N_LIB_PRIVATE N_NIMCALL(void, checkSlicesAreDisjoint__oEYSvTAgV5TtcIl6O6tf7A_2)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c);
N_LIB_PRIVATE N_NIMCALL(void, overlap__Pk7bQd709cefQqdqSKch4Kg)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* d);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, subStride__Eo27jklJC4f01fawyLM2Vw)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, buildAdd__jGtL4PYHin0Ec4iHpFgCdA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, NI64 b, tyObject_Operators__apNm0zcYroUpNRird62c9aQ* o);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, shallowCopy__Dsjo9bte8vGxzhtcSrsTyiQ_3)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameTree__Uv9a9aANFtV79cIvUP5jEeyVA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(NI64, simpleSlice__VGfXCY3TCP9cSnuVXj9a9a8nQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(NI64, stride__qzhxkwLh9b1dUrty1QrNeVQ)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, checkArgs__Cwo3r2QBfdI5juR3DQ1mAQ)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__vokyXY9cZDshCSxFKChhG9bg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newSym__IXbidcxhXTQGZY9abN63Cxg)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symKind, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*, getIdent__9coBOmdXN09be4rJvXK6fQGQ)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* ic, NimStringDesc* identifier);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(void, addVar__qOCBdprWtK4hxer73SEdQA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, genAddrOf__llCeDV6q0X9bzDY9agj6OpdQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag typeKind);
N_LIB_PRIVATE N_NIMCALL(void, generateAliasChecks__qsgth9a5dt8cle6qTmFBAtQ)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result);
N_LIB_PRIVATE N_NIMCALL(void, add__P8dDSotTW25BkfbyspojGg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, callCodegenProc__6cD4vACMYqPEkcqC9cypTrw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NimStringDesc* name, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg1, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg2, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg3, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* optionalArgs);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformSpawn__E6FEP3eiSuBpDSuWg6Avkg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* barrier);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformSlices__H1scsKXQAJ9cBTNEu0yVKsw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, createMagic__MzNJxZ0htpjW89c9b2wBN5rQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NimStringDesc* name, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw, spawnResult__115WOpmSjJFT089amuDIXdA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, NIM_BOOL inParallel);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, wrapProcForSpawn__9cWXyScktPXvQmRC9aBs0ADw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* spawnExpr, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* retType, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* barrier, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* dest);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformSpawnSons__E6FEP3eiSuBpDSuWg6Avkg_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* barrier);

/* section: NIM_merge_DATA */
N_LIB_PRIVATE TNimType NTI__PyZQX2tcVOc67gX80PLPxA_;
extern TNimType NTI__K9bspPztfoWajecnwjyHuYQ_;
extern TNimType NTI__fKfcLzXYiz5jNu3NH3Tv8Q_;
N_LIB_PRIVATE TNimType NTI__ogNRjad5Q2m49bwMa6pnI3w_;
extern TNimType NTI__VaVACK0bpYmqIQ0mKcHfQQ_;
N_LIB_PRIVATE TNimType NTI__JsYE17s5Dad5mZDxLHKgaw_;
extern TNimType NTI__DfgJFJEYoj4YBAHLZPl5lQ_;
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_6, "+=", 2);
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_7, "[]", 2);
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_8, "invalid usage of counter after increment", 40);
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_10, "/home/runner/work/nightlies/nightlies/nim/compiler/semparallel."
"nim", 66);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_9 = {((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_10),
((NI) 123),
((NI) 16)}
;
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_11, "cannot prove: ", 14);
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_12, " <= ", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_13 = {((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_10),
((NI) 132),
((NI) 11)}
;
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_14, "can prove: ", 11);
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_15, " > ", 3);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_16 = {((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_10),
((NI) 136),
((NI) 11)}
;
extern TNimType NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_;
N_LIB_PRIVATE TNimType NTI__SBroeDF0AeeG8DGttrMudQ_;
extern TNimType NTI__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTI__6lRdzb9aFAlo79bGaEawph6g_;
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_18, "[]=", 3);
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_19, "invalid control flow for \'parallel\'", 35);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_20 = {((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_10),
((NI) 355),
((NI) 14)}
;
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_21, "slot already has a lower bound", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_22 = {((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_10),
((NI) 371),
((NI) 31)}
;
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_23, "\'parallel\' section without \'spawn\'", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_24 = {((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_10),
((NI) 480),
((NI) 14)}
;
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_25, "cannot prove: $# > $#; required for ($#)..($#) disjoint from ($"
"#)..($#)", 71);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_26 = {((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_10),
((NI) 167),
((NI) 13)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_27 = {((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_10),
((NI) 173),
((NI) 13)}
;
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_28, "($#)..($#) not disjoint from ($#)..($#)", 39);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_29 = {((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_10),
((NI) 177),
((NI) 13)}
;
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_30, "cannot prove ($#)..($#) disjoint from ($#)..($#)", 48);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_31 = {((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_10),
((NI) 250),
((NI) 22)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_32 = {((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_10),
((NI) 253),
((NI) 20)}
;
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_33, "barrier", 7);
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_34, "Barrier", 7);
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_35, "openBarrier", 11);
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_36, "invalid context for \'spawn\'", 27);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_37 = {((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_10),
((NI) 432),
((NI) 34)}
;
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_38, "slice", 5);
STRING_LITERAL(TM__Itl65swq3r8pqY8Wou1vYA_39, "closeBarrier", 12);

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(void, initAnalysisCtx__GoSHD4Mq66yV2bANMNqkiA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* Result) {
	unsureAsgnRef((void**)&(*Result).locals, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).slices, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).guards.s, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).guards.o.opNot, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).guards.o.opContains, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).guards.o.opLe, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).guards.o.opLt, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).guards.o.opAnd, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).guards.o.opOr, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).guards.o.opIsNil, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).guards.o.opEq, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).guards.o.opAdd, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).guards.o.opSub, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).guards.o.opMul, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).guards.o.opDiv, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).guards.o.opLen, NIM_NIL);
	(*Result).guards.beSmart = 0;
	unsureAsgnRef((void**)&(*Result).args, NIM_NIL);
	(*Result).spawns = 0;
	(*Result).currentSpawnId = 0;
	(*Result).inLoop = 0;
	unsureAsgnRef((void**)&(*Result).graph, NIM_NIL);
	unsureAsgnRef((void**) (&(*Result).locals), NIM_NIL);
	unsureAsgnRef((void**) (&(*Result).slices), NIM_NIL);
	unsureAsgnRef((void**) (&(*Result).args), NIM_NIL);
	unsureAsgnRef((void**) (&(*Result).guards.s), NIM_NIL);
	initOperators__3Mq69aIkPINTsOZ4I5g1jZA(g, (&(*Result).guards.o));
	unsureAsgnRef((void**) (&(*Result).graph), g);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSingleAssignable__1EjP4hSli31mWSG19b8VOAw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	if (!(T1_)) goto LA2_;
	s = (*n)._kind_4.sym;
	T3_ = (NIM_BOOL)0;
	T3_ = ((2097696 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	if (!(T3_)) goto LA4_;
	T3_ = ((131080 & (*s).flags) == 0);
	LA4_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLocal__1EjP4hSli31mWSG19b8VOAw_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	if (!(T1_)) goto LA2_;
	s = (*n)._kind_4.sym;
	T3_ = (NIM_BOOL)0;
	T3_ = ((2100000 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	if (!(T3_)) goto LA4_;
	T3_ = ((131080 & (*s).flags) == 0);
	LA4_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, lookupSlot__mQQqEPn8XV0sbu4TVfeZfQ)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NI result;
{	result = (NI)0;
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*c).locals ? (*c).locals->Sup.len : 0);
		colontmp_ = T2_;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				{
					NIM_BOOL T7_;
					T7_ = (NIM_BOOL)0;
					T7_ = ((*c).locals->data[i].v == s);
					if (T7_) goto LA8_;
					T7_ = ((*c).locals->data[i].alias == s);
					LA8_: ;
					if (!T7_) goto LA9_;
					result = i;
					goto BeforeRet_;
				}
				LA9_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	result = ((NI) -1);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_NIMCALL(void, Marker_tySequence__JsYE17s5Dad5mZDxLHKgaw)(void* p, NI op) {
	tySequence__JsYE17s5Dad5mZDxLHKgaw* a;
	NI T1_;
	a = (tySequence__JsYE17s5Dad5mZDxLHKgaw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].v, op);
	nimGCvisit((void*)a->data[T1_].alias, op);
	nimGCvisit((void*)a->data[T1_].lower, op);
	nimGCvisit((void*)a->data[T1_].upper, op);
	nimGCvisit((void*)a->data[T1_].stride, op);
	}
}
static N_INLINE(tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA*, X5BX5D___iBfZWB3WtvXDdbJW9aq8zMgsystem)(tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA* s, NI sLen_0, NI i) {
	tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA* result;
	result = (tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA*)0;
	result = (&s[(NI)(sLen_0 - i)]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA*, getSlot__BqDp9cVNfT8XYSnaRrYoEjg)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v) {
	tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA* result;
	NI s;
	NI T5_;
	tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA* T6_;
{	result = (tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA*)0;
	s = lookupSlot__mQQqEPn8XV0sbu4TVfeZfQ((&(*c)), v);
	{
		if (!(((NI) 0) <= s)) goto LA3_;
		result = (&(*c).locals->data[s]);
		goto BeforeRet_;
	}
	LA3_: ;
	T5_ = ((*c).locals ? (*c).locals->Sup.len : 0);
	unsureAsgnRef((void**) (&(*c).locals), (tySequence__JsYE17s5Dad5mZDxLHKgaw*) setLengthSeqV2(&((*c).locals)->Sup, (&NTI__JsYE17s5Dad5mZDxLHKgaw_), ((NI) ((NI)(T5_ + ((NI) 1))))));
	T6_ = (tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA*)0;
	T6_ = X5BX5D___iBfZWB3WtvXDdbJW9aq8zMgsystem((*c).locals->data, ((*c).locals ? (*c).locals->Sup.len : 0), ((NI) 1));
	unsureAsgnRef((void**) (&(*T6_).v), v);
	result = X5BX5D___iBfZWB3WtvXDdbJW9aq8zMgsystem((*c).locals->data, ((*c).locals ? (*c).locals->Sup.len : 0), ((NI) 1));
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__P89cqdlERShb9alU3iC0yj8wast(n);
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(void, gatherArgs__PaRoa8NLdkCWN1FglnKPWw_2)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* root;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				root = getRoot__QppXrRxPfamDSGF2rYPMlw((*n)._kind_6.sons->data[i]);
				{
					if (!!((root == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA6_;
					{
						NI T17_;
						{
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w** r;
							NI i_3;
							NI L;
							NI T10_;
							r = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w**)0;
							i_3 = ((NI) 0);
							T10_ = ((*c).args ? (*c).args->Sup.len : 0);
							L = T10_;
							{
								while (1) {
									if (!(i_3 < L)) goto LA12;
									r = &(*c).args->data[i_3];
									{
										if (!((*r) == root)) goto LA15_;
										goto LA8;
									}
									LA15_: ;
									i_3 += ((NI) 1);
								} LA12: ;
							}
						}
						unsureAsgnRef((void**) (&(*c).args), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) incrSeqV3((TGenericSeq*)((*c).args), (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_)));
						T17_ = (*c).args->Sup.len++;
						asgnRef((void**) (&(*c).args->data[T17_]), root);
					} LA8: ;
				}
				LA6_: ;
				gatherArgs__PaRoa8NLdkCWN1FglnKPWw_2(c, (*n)._kind_6.sons->data[i]);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, analyseSons__PaRoa8NLdkCWN1FglnKPWw_3)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				analyse__PaRoa8NLdkCWN1FglnKPWw(c, (*n)._kind_6.sons->data[i]);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, fromSystem__koLUZmQCBRKFmUFVrVvuPQastalgo)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* op) {
	NIM_BOOL result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T1_;
	result = (NIM_BOOL)0;
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = getModule__xfh8ar7fDxVX2A4OO9b5sqQ(op);
	result = (((*T1_).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, min__hw07ic0yxYJqPZr6HDlP5A)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!(a == 0)) goto LA3_;
		result = b;
	}
	goto LA1_;
	LA3_: ;
	{
		if (!((*a)._kind_1.intVal < (*b)._kind_1.intVal)) goto LA6_;
		result = a;
	}
	goto LA1_;
	LA6_: ;
	{
		result = b;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkLocal__2i9bGbP4MqLVXtqxlsPOB9bg)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		NI s;
		T3_ = (NIM_BOOL)0;
		T3_ = isLocal__1EjP4hSli31mWSG19b8VOAw_2(n);
		if (!T3_) goto LA4_;
		s = lookupSlot__mQQqEPn8XV0sbu4TVfeZfQ(c, (*n)._kind_4.sym);
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = (((NI) 0) <= s);
			if (!(T8_)) goto LA9_;
			T8_ = !(((*c).locals->data[s].stride == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			LA9_: ;
			if (!T8_) goto LA10_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_8), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__Itl65swq3r8pqY8Wou1vYA_9, NIM_FALSE);
		}
		LA10_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA15;
					i = i_2;
					checkLocal__2i9bGbP4MqLVXtqxlsPOB9bg(c, (*n)._kind_6.sons->data[i]);
					i_2 += ((NI) 1);
				} LA15: ;
			}
		}
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addLowerBoundAsFacts__oEYSvTAgV5TtcIl6O6tf7A)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c) {
	{
		tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA* v;
		NI i;
		NI L;
		NI T2_;
		v = (tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA*)0;
		i = ((NI) 0);
		T2_ = ((*c).locals ? (*c).locals->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				v = (&(*c).locals->data[i]);
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T9_;
					if (!!((*v).blacklisted)) goto LA7_;
					T9_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T9_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg((*v).v);
					addFactLe__i9aAoMzJNp9aw6KruJgPZ0Ng((&(*c).guards), (*v).lower, T9_);
				}
				LA7_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__M04YC71iJg1N7gBF3HZTngsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, checkLe__UUqGf4gbiwbVS5sZvK0DnQ)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b) {
	tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA T1_;
	T1_ = (tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA)0;
	T1_ = proveLe__gquZ4TuLCn9anC5O4OWI4Og((&(*c).guards), a, b);
	switch (T1_) {
	case ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 0):
	{
		NimStringDesc* T3_;
		NimStringDesc* T4_;
		NimStringDesc* T5_;
		T3_ = (NimStringDesc*)0;
		T4_ = (NimStringDesc*)0;
		T4_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(a, 0);
		T5_ = (NimStringDesc*)0;
		T5_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(b, 0);
		T3_ = rawNewString((T4_ ? T4_->Sup.len : 0) + (T5_ ? T5_->Sup.len : 0) + 18);
appendString(T3_, ((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_11));
appendString(T3_, T4_);
appendString(T3_, ((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_12));
appendString(T3_, T5_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 39), T3_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__Itl65swq3r8pqY8Wou1vYA_13, NIM_FALSE);
	}
	break;
	case ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 2):
	{
	}
	break;
	case ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 1):
	{
		NimStringDesc* T8_;
		NimStringDesc* T9_;
		NimStringDesc* T10_;
		T8_ = (NimStringDesc*)0;
		T9_ = (NimStringDesc*)0;
		T9_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(a, 0);
		T10_ = (NimStringDesc*)0;
		T10_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(b, 0);
		T8_ = rawNewString((T9_ ? T9_->Sup.len : 0) + (T10_ ? T10_->Sup.len : 0) + 14);
appendString(T8_, ((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_14));
appendString(T8_, T9_);
appendString(T8_, ((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_15));
appendString(T8_, T10_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 39), T8_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__Itl65swq3r8pqY8Wou1vYA_16, NIM_FALSE);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, checkBounds__jQXLtc0O7sNmd6nxua4Juw)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arr, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* idx) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T2_;
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = lowBound__Esza4n69a5U9bzlDTK04VArg((*(*c).graph).config, arr);
	checkLe__UUqGf4gbiwbVS5sZvK0DnQ(c, T1_, idx);
	T2_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T2_ = highBound__9cbEq5HLZRHFpEqTjJwMYDA((*(*c).graph).config, arr, (&(*c).guards.o));
	checkLe__UUqGf4gbiwbVS5sZvK0DnQ(c, idx, T2_);
}
static N_NIMCALL(void, Marker_tySequence__6lRdzb9aFAlo79bGaEawph6g)(void* p, NI op) {
	tySequence__6lRdzb9aFAlo79bGaEawph6g* a;
	NI T1_;
	a = (tySequence__6lRdzb9aFAlo79bGaEawph6g*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	nimGCvisit((void*)a->data[T1_].Field1, op);
	nimGCvisit((void*)a->data[T1_].Field2, op);
	}
}
N_LIB_PRIVATE N_NIMCALL(void, addSlice__bWhVAxARSLxqbiKhEiF3ig)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le_2;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri_2;
	NI oldState;
	NI T1_;
	tyTuple__SBroeDF0AeeG8DGttrMudQ T2_;
	NI T3_;
	checkLocal__2i9bGbP4MqLVXtqxlsPOB9bg((&(*c)), n);
	le_2 = canon__Jdq9bmYnl9bApH9aGfXEZQN8Q_2(le, (&(*c).guards.o));
	ri_2 = canon__Jdq9bmYnl9bApH9aGfXEZQN8Q_2(ri, (&(*c).guards.o));
	T1_ = ((*c).guards.s ? (*c).guards.s->Sup.len : 0);
	oldState = T1_;
	addLowerBoundAsFacts__oEYSvTAgV5TtcIl6O6tf7A(c);
	checkBounds__jQXLtc0O7sNmd6nxua4Juw((&(*c)), x, le_2);
	checkBounds__jQXLtc0O7sNmd6nxua4Juw((&(*c)), x, ri_2);
	unsureAsgnRef((void**) (&(*c).guards.s), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*c).guards.s)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (oldState))));
	nimZeroMem((void*)(&T2_), sizeof(tyTuple__SBroeDF0AeeG8DGttrMudQ));
	T2_.Field0 = x;
	T2_.Field1 = le_2;
	T2_.Field2 = ri_2;
	T2_.Field3 = (*c).currentSpawnId;
	T2_.Field4 = (((NI) 0) < (*c).inLoop);
	unsureAsgnRef((void**) (&(*c).slices), (tySequence__6lRdzb9aFAlo79bGaEawph6g*) incrSeqV3((TGenericSeq*)((*c).slices), (&NTI__6lRdzb9aFAlo79bGaEawph6g_)));
	T3_ = (*c).slices->Sup.len++;
	genericAssign((void*)(&(*c).slices->data[T3_]), (void*)(&T2_), (&NTI__SBroeDF0AeeG8DGttrMudQ_));
}
N_LIB_PRIVATE N_NIMCALL(void, analyseCall__lurTQ8a1NGs6iZ6f4zXjoQ)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* op) {
	{
		NI oldSpawnId;
		if (!((*op).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 194))) goto LA3_;
		(*c).spawns += ((NI) 1);
		oldSpawnId = (*c).currentSpawnId;
		(*c).currentSpawnId = (*c).spawns;
		gatherArgs__PaRoa8NLdkCWN1FglnKPWw_2(c, (*n)._kind_6.sons->data[((NI) 1)]);
		analyseSons__PaRoa8NLdkCWN1FglnKPWw_3(c, n);
		(*c).currentSpawnId = oldSpawnId;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		NIM_BOOL T8_;
		T6_ = (NIM_BOOL)0;
		T6_ = ((*op).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 29));
		if (T6_) goto LA7_;
		T8_ = (NIM_BOOL)0;
		T8_ = eqStrings((*(*op).name).s, ((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_6));
		if (!(T8_)) goto LA9_;
		T8_ = fromSystem__koLUZmQCBRKFmUFVrVvuPQastalgo(op);
		LA9_: ;
		T6_ = T8_;
		LA7_: ;
		if (!T6_) goto LA10_;
		{
			NIM_BOOL T14_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* incr;
			T14_ = (NIM_BOOL)0;
			T14_ = isLocal__1EjP4hSli31mWSG19b8VOAw_2((*n)._kind_6.sons->data[((NI) 1)]);
			if (!T14_) goto LA15_;
			incr = skipConv__BH9abOhPX8pH0DnEWlRxmlw((*n)._kind_6.sons->data[((NI) 2)]);
			{
				NIM_BOOL T19_;
				tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA* slot;
				T19_ = (NIM_BOOL)0;
				T19_ = ((*incr).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) && (*incr).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 14));
				if (!(T19_)) goto LA20_;
				T19_ = (IL64(0) < (*incr)._kind_1.intVal);
				LA20_: ;
				if (!T19_) goto LA21_;
				slot = getSlot__BqDp9cVNfT8XYSnaRrYoEjg(c, (*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym);
				unsureAsgnRef((void**) (&(*slot).stride), min__hw07ic0yxYJqPZr6HDlP5A((*slot).stride, incr));
			}
			LA21_: ;
		}
		LA15_: ;
		analyseSons__PaRoa8NLdkCWN1FglnKPWw_3(c, n);
	}
	goto LA1_;
	LA10_: ;
	{
		NIM_BOOL T24_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* slice;
		T24_ = (NIM_BOOL)0;
		T24_ = eqStrings((*(*op).name).s, ((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_7));
		if (!(T24_)) goto LA25_;
		T24_ = fromSystem__koLUZmQCBRKFmUFVrVvuPQastalgo(op);
		LA25_: ;
		if (!T24_) goto LA26_;
		slice = skipStmtList__UPSW0jLTX5qJL51YMUAHgw_4((*n)._kind_6.sons->data[((NI) 2)]);
		addSlice__bWhVAxARSLxqbiKhEiF3ig(c, n, (*n)._kind_6.sons->data[((NI) 1)], (*slice)._kind_6.sons->data[((NI) 1)], (*slice)._kind_6.sons->data[((NI) 2)]);
		analyseSons__PaRoa8NLdkCWN1FglnKPWw_3(c, n);
	}
	goto LA1_;
	LA26_: ;
	{
		NIM_BOOL T29_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* slice_2;
		T29_ = (NIM_BOOL)0;
		T29_ = eqStrings((*(*op).name).s, ((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_18));
		if (!(T29_)) goto LA30_;
		T29_ = fromSystem__koLUZmQCBRKFmUFVrVvuPQastalgo(op);
		LA30_: ;
		if (!T29_) goto LA31_;
		slice_2 = skipStmtList__UPSW0jLTX5qJL51YMUAHgw_4((*n)._kind_6.sons->data[((NI) 2)]);
		addSlice__bWhVAxARSLxqbiKhEiF3ig(c, n, (*n)._kind_6.sons->data[((NI) 1)], (*slice_2)._kind_6.sons->data[((NI) 1)], (*slice_2)._kind_6.sons->data[((NI) 2)]);
		analyseSons__PaRoa8NLdkCWN1FglnKPWw_3(c, n);
	}
	goto LA1_;
	LA31_: ;
	{
		analyseSons__PaRoa8NLdkCWN1FglnKPWw_3(c, n);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, analyseCase__PaRoa8NLdkCWN1FglnKPWw_4)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI oldFacts;
	NI T1_;
	analyse__PaRoa8NLdkCWN1FglnKPWw(c, (*n)._kind_6.sons->data[((NI) 0)]);
	T1_ = ((*c).guards.s ? (*c).guards.s->Sup.len : 0);
	oldFacts = T1_;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				branch = (*n)._kind_6.sons->data[i];
				unsureAsgnRef((void**) (&(*c).guards.s), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*c).guards.s)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (oldFacts))));
				addCaseBranchFacts__c6dE6J2nt777cGY9brPJUJA((&(*c).guards), n, i);
				{
					NI i_3;
					NI colontmp__2;
					NI i_4;
					i_3 = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(branch);
					i_4 = ((NI) 0);
					{
						while (1) {
							if (!(i_4 < colontmp__2)) goto LA7;
							i_3 = i_4;
							analyse__PaRoa8NLdkCWN1FglnKPWw(c, (*branch)._kind_6.sons->data[i_3]);
							i_4 += ((NI) 1);
						} LA7: ;
					}
				}
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	unsureAsgnRef((void**) (&(*c).guards.s), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*c).guards.s)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (oldFacts))));
}
N_LIB_PRIVATE N_NIMCALL(void, analyseIf__PaRoa8NLdkCWN1FglnKPWw_5)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI oldFacts;
	NI T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T2_;
	analyse__PaRoa8NLdkCWN1FglnKPWw(c, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]);
	T1_ = ((*c).guards.s ? (*c).guards.s->Sup.len : 0);
	oldFacts = T1_;
	T2_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T2_ = canon__Jdq9bmYnl9bApH9aGfXEZQN8Q_2((*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)], (&(*c).guards.o));
	addFact__ybuIey7mglQLm61kxh9aaLg((&(*c).guards), T2_);
	analyse__PaRoa8NLdkCWN1FglnKPWw(c, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch;
				if (!(i_2 < colontmp_)) goto LA5;
				i = i_2;
				branch = (*n)._kind_6.sons->data[i];
				unsureAsgnRef((void**) (&(*c).guards.s), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*c).guards.s)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (oldFacts))));
				{
					NI j;
					NI colontmp__2;
					NI res;
					j = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__2 = (NI)(i - ((NI) 1));
					res = ((NI) 0);
					{
						while (1) {
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T9_;
							if (!(res <= colontmp__2)) goto LA8;
							j = res;
							T9_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T9_ = canon__Jdq9bmYnl9bApH9aGfXEZQN8Q_2((*(*n)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 0)], (&(*c).guards.o));
							addFactNeg__no3iuruVlFxE0wQ8HA9b4ZA_2((&(*c).guards), T9_);
							res += ((NI) 1);
						} LA8: ;
					}
				}
				{
					NI T12_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T15_;
					T12_ = (NI)0;
					T12_ = len__P89cqdlERShb9alU3iC0yj8wast(branch);
					if (!(((NI) 1) < T12_)) goto LA13_;
					T15_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T15_ = canon__Jdq9bmYnl9bApH9aGfXEZQN8Q_2((*branch)._kind_6.sons->data[((NI) 0)], (&(*c).guards.o));
					addFact__ybuIey7mglQLm61kxh9aaLg((&(*c).guards), T15_);
				}
				LA13_: ;
				{
					NI i_3;
					NI colontmp__3;
					NI i_4;
					i_3 = (NI)0;
					colontmp__3 = (NI)0;
					colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(branch);
					i_4 = ((NI) 0);
					{
						while (1) {
							if (!(i_4 < colontmp__3)) goto LA18;
							i_3 = i_4;
							analyse__PaRoa8NLdkCWN1FglnKPWw(c, (*branch)._kind_6.sons->data[i_3]);
							i_4 += ((NI) 1);
						} LA18: ;
					}
				}
				i_2 += ((NI) 1);
			} LA5: ;
		}
	}
	unsureAsgnRef((void**) (&(*c).guards.s), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*c).guards.s)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (oldFacts))));
}
N_LIB_PRIVATE N_NIMCALL(void, analyse__PaRoa8NLdkCWN1FglnKPWw)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* value;
		y = skipConv__BH9abOhPX8pH0DnEWlRxmlw((*n)._kind_6.sons->data[((NI) 1)]);
		{
			NIM_BOOL T4_;
			tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA* slot;
			T4_ = (NIM_BOOL)0;
			T4_ = isSingleAssignable__1EjP4hSli31mWSG19b8VOAw((*n)._kind_6.sons->data[((NI) 0)]);
			if (!(T4_)) goto LA5_;
			T4_ = isLocal__1EjP4hSli31mWSG19b8VOAw_2(y);
			LA5_: ;
			if (!T4_) goto LA6_;
			slot = getSlot__BqDp9cVNfT8XYSnaRrYoEjg(c, (*y)._kind_4.sym);
			unsureAsgnRef((void**) (&(*slot).alias), (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
		}
		goto LA2_;
		LA6_: ;
		{
			NIM_BOOL T9_;
			tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA* slot_2;
			T9_ = (NIM_BOOL)0;
			T9_ = isLocal__1EjP4hSli31mWSG19b8VOAw_2((*n)._kind_6.sons->data[((NI) 0)]);
			if (!T9_) goto LA10_;
			slot_2 = getSlot__BqDp9cVNfT8XYSnaRrYoEjg(c, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
			(*slot_2).blacklisted = NIM_TRUE;
		}
		goto LA2_;
		LA10_: ;
		LA2_: ;
		invalidateFacts__no3iuruVlFxE0wQ8HA9b4ZA((&(*c).guards), (*n)._kind_6.sons->data[((NI) 0)]);
		value = (*n)._kind_6.sons->data[((NI) 1)];
		{
			tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg T14_;
			NI oldSpawnId;
			T14_ = (tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg)0;
			T14_ = getMagic__4W1ZJaFiusqlhViRx9cbM9bw(value);
			if (!(T14_ == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 194))) goto LA15_;
			(*c).spawns += ((NI) 1);
			oldSpawnId = (*c).currentSpawnId;
			(*c).currentSpawnId = (*c).spawns;
			gatherArgs__PaRoa8NLdkCWN1FglnKPWw_2(c, (*value)._kind_6.sons->data[((NI) 1)]);
			analyseSons__PaRoa8NLdkCWN1FglnKPWw_3(c, (*value)._kind_6.sons->data[((NI) 1)]);
			analyse__PaRoa8NLdkCWN1FglnKPWw(c, (*n)._kind_6.sons->data[((NI) 0)]);
			(*c).currentSpawnId = oldSpawnId;
		}
		goto LA12_;
		LA15_: ;
		{
			analyseSons__PaRoa8NLdkCWN1FglnKPWw_3(c, n);
		}
		LA12_: ;
		addAsgnFact__0CHSuARDyWZ57Xrosqy78w((&(*c).guards), (*n)._kind_6.sons->data[((NI) 0)], y);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		{
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA21_;
			analyseCall__lurTQ8a1NGs6iZ6f4zXjoQ(c, n, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
		}
		goto LA19_;
		LA21_: ;
		{
			analyseSons__PaRoa8NLdkCWN1FglnKPWw_3(c, n);
		}
		LA19_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
	{
		{
			NIM_BOOL T27_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T29_;
			T27_ = (NIM_BOOL)0;
			T27_ = !(((*(*n)._kind_6.sons->data[((NI) 0)]).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T27_)) goto LA28_;
			T29_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T29_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36275087632017680));
			T27_ = !(((*T29_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18)));
			LA28_: ;
			if (!T27_) goto LA30_;
			addSlice__bWhVAxARSLxqbiKhEiF3ig(c, n, (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)], (*n)._kind_6.sons->data[((NI) 1)]);
		}
		LA30_: ;
		analyseSons__PaRoa8NLdkCWN1FglnKPWw_3(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 108):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 106):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 154):
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_19), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__Itl65swq3r8pqY8Wou1vYA_20, NIM_FALSE);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
			it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* value_2;
						NIM_BOOL isSpawned;
						tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg T38_;
						if (!(i_2 < colontmp_)) goto LA37;
						i = i_2;
						it = (*n)._kind_6.sons->data[i];
						value_2 = lastSon__UPSW0jLTX5qJL51YMUAHgw(it);
						T38_ = (tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg)0;
						T38_ = getMagic__4W1ZJaFiusqlhViRx9cbM9bw(value_2);
						isSpawned = (T38_ == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 194));
						{
							NI oldSpawnId_2;
							if (!isSpawned) goto LA41_;
							(*c).spawns += ((NI) 1);
							oldSpawnId_2 = (*c).currentSpawnId;
							(*c).currentSpawnId = (*c).spawns;
							gatherArgs__PaRoa8NLdkCWN1FglnKPWw_2(c, (*value_2)._kind_6.sons->data[((NI) 1)]);
							analyseSons__PaRoa8NLdkCWN1FglnKPWw_3(c, (*value_2)._kind_6.sons->data[((NI) 1)]);
							(*c).currentSpawnId = oldSpawnId_2;
						}
						LA41_: ;
						{
							if (!!(((*value_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA45_;
							{
								NI j;
								NI colontmp__2;
								NI T48_;
								NI i_3;
								j = (NI)0;
								colontmp__2 = (NI)0;
								T48_ = (NI)0;
								T48_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
								colontmp__2 = (NI)(T48_ - ((NI) 2));
								i_3 = ((NI) 0);
								{
									while (1) {
										if (!(i_3 < colontmp__2)) goto LA50;
										j = i_3;
										{
											NIM_BOOL T53_;
											tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA* slot_3;
											T53_ = (NIM_BOOL)0;
											T53_ = isLocal__1EjP4hSli31mWSG19b8VOAw_2((*it)._kind_6.sons->data[j]);
											if (!T53_) goto LA54_;
											slot_3 = getSlot__BqDp9cVNfT8XYSnaRrYoEjg(c, (*(*it)._kind_6.sons->data[j])._kind_4.sym);
											{
												if (!((*slot_3).lower == 0)) goto LA58_;
												unsureAsgnRef((void**) (&(*slot_3).lower), value_2);
											}
											goto LA56_;
											LA58_: ;
											{
												internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*it).info, ((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_21), TM__Itl65swq3r8pqY8Wou1vYA_22);
											}
											LA56_: ;
										}
										LA54_: ;
										i_3 += ((NI) 1);
									} LA50: ;
								}
							}
							{
								if (!!(isSpawned)) goto LA63_;
								analyse__PaRoa8NLdkCWN1FglnKPWw(c, value_2);
							}
							LA63_: ;
						}
						LA45_: ;
						i_2 += ((NI) 1);
					} LA37: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 97):
	{
		analyseCase__PaRoa8NLdkCWN1FglnKPWw_4(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 93):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 48):
	{
		analyseIf__PaRoa8NLdkCWN1FglnKPWw_5(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96):
	{
		analyse__PaRoa8NLdkCWN1FglnKPWw(c, (*n)._kind_6.sons->data[((NI) 0)]);
		(*c).inLoop += ((NI) 1);
		{
			NIM_BOOL T70_;
			T70_ = (NIM_BOOL)0;
			T70_ = isTrue__9cP6JNeOKqczaXCI4Zo4SBQ_5((*n)._kind_6.sons->data[((NI) 0)]);
			if (!T70_) goto LA71_;
			analyseSons__PaRoa8NLdkCWN1FglnKPWw_3(c, (*n)._kind_6.sons->data[((NI) 1)]);
		}
		goto LA68_;
		LA71_: ;
		{
			NI oldState;
			NI T74_;
			NI oldFacts;
			NI T75_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T76_;
			T74_ = ((*c).locals ? (*c).locals->Sup.len : 0);
			oldState = T74_;
			T75_ = ((*c).guards.s ? (*c).guards.s->Sup.len : 0);
			oldFacts = T75_;
			T76_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T76_ = canon__Jdq9bmYnl9bApH9aGfXEZQN8Q_2((*n)._kind_6.sons->data[((NI) 0)], (&(*c).guards.o));
			addFact__ybuIey7mglQLm61kxh9aaLg((&(*c).guards), T76_);
			analyse__PaRoa8NLdkCWN1FglnKPWw(c, (*n)._kind_6.sons->data[((NI) 1)]);
			unsureAsgnRef((void**) (&(*c).locals), (tySequence__JsYE17s5Dad5mZDxLHKgaw*) setLengthSeqV2(&((*c).locals)->Sup, (&NTI__JsYE17s5Dad5mZDxLHKgaw_), ((NI) (oldState))));
			unsureAsgnRef((void**) (&(*c).guards.s), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*c).guards.s)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (oldFacts))));
			{
				NIM_BOOL T79_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T82_;
				T79_ = (NIM_BOOL)0;
				T79_ = hasSubnodeWith__SQs4BrslojahuO1o7NDT4Q((*n)._kind_6.sons->data[((NI) 1)], ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110));
				if (!!(T79_)) goto LA80_;
				T82_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T82_ = canon__Jdq9bmYnl9bApH9aGfXEZQN8Q_2((*n)._kind_6.sons->data[((NI) 0)], (&(*c).guards.o));
				addFactNeg__no3iuruVlFxE0wQ8HA9b4ZA_2((&(*c).guards), T82_);
			}
			LA80_: ;
		}
		LA68_: ;
		(*c).inLoop -= ((NI) 1);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 80):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 101):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 90):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
	}
	break;
	default:
	{
		analyseSons__PaRoa8NLdkCWN1FglnKPWw_3(c, n);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, overlap__Pk7bQd709cefQqdqSKch4Kg)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* d) {
	tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA T1_;
	T1_ = (tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA)0;
	T1_ = proveLe__gquZ4TuLCn9anC5O4OWI4Og(m, c, y);
	switch (T1_) {
	case ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 0):
	{
		tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA T3_;
		T3_ = (tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA)0;
		T3_ = proveLe__gquZ4TuLCn9anC5O4OWI4Og(m, x, d);
		switch (T3_) {
		case ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 1):
		{
		}
		break;
		case ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 0):
		case ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 2):
		{
			tyArray__yt5VDPNtUGx9cBkOVakHwdQ T6_;
			NimStringDesc* T7_;
			nimZeroMem((void*)T6_, sizeof(tyArray__yt5VDPNtUGx9cBkOVakHwdQ));
			T6_[0] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(c, 0);
			T6_[1] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(y, 0);
			T6_[2] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(x, 0);
			T6_[3] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(y, 0);
			T6_[4] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(c, 0);
			T6_[5] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(d, 0);
			T7_ = (NimStringDesc*)0;
			T7_ = nsuFormatOpenArray(((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_25), T6_, 6);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, (*x).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 39), T7_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__Itl65swq3r8pqY8Wou1vYA_26, NIM_FALSE);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 2):
	{
		tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA T9_;
		T9_ = (tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA)0;
		T9_ = proveLe__gquZ4TuLCn9anC5O4OWI4Og(m, x, d);
		switch (T9_) {
		case ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 0):
		{
			tyArray__yt5VDPNtUGx9cBkOVakHwdQ T11_;
			NimStringDesc* T12_;
			nimZeroMem((void*)T11_, sizeof(tyArray__yt5VDPNtUGx9cBkOVakHwdQ));
			T11_[0] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(x, 0);
			T11_[1] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(d, 0);
			T11_[2] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(x, 0);
			T11_[3] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(y, 0);
			T11_[4] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(c, 0);
			T11_[5] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(d, 0);
			T12_ = (NimStringDesc*)0;
			T12_ = nsuFormatOpenArray(((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_25), T11_, 6);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, (*x).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 39), T12_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__Itl65swq3r8pqY8Wou1vYA_27, NIM_FALSE);
		}
		break;
		case ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 2):
		{
			tyArray__yt5VDPNtUGx9cBkOVakHwdQ T14_;
			NimStringDesc* T15_;
			nimZeroMem((void*)T14_, sizeof(tyArray__yt5VDPNtUGx9cBkOVakHwdQ));
			T14_[0] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(c, 0);
			T14_[1] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(y, 0);
			T14_[2] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(x, 0);
			T14_[3] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(y, 0);
			T14_[4] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(c, 0);
			T14_[5] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(d, 0);
			T15_ = (NimStringDesc*)0;
			T15_ = nsuFormatOpenArray(((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_28), T14_, 6);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, (*x).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 39), T15_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__Itl65swq3r8pqY8Wou1vYA_29, NIM_FALSE);
		}
		break;
		case ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 1):
		{
		}
		break;
		}
	}
	break;
	case ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 1):
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, subStride__Eo27jklJC4f01fawyLM2Vw)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		NI s;
		T3_ = (NIM_BOOL)0;
		T3_ = isLocal__1EjP4hSli31mWSG19b8VOAw_2(n);
		if (!T3_) goto LA4_;
		s = lookupSlot__mQQqEPn8XV0sbu4TVfeZfQ(c, (*n)._kind_4.sym);
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = (((NI) 0) <= s);
			if (!(T8_)) goto LA9_;
			T8_ = !(((*c).locals->data[s].stride == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			LA9_: ;
			if (!T8_) goto LA10_;
			result = buildAdd__jGtL4PYHin0Ec4iHpFgCdA(n, (*(*c).locals->data[s].stride)._kind_1.intVal, (&(*c).guards.o));
		}
		goto LA6_;
		LA10_: ;
		{
			result = n;
		}
		LA6_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		NI T14_;
		T14_ = (NI)0;
		T14_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
		if (!(((NI) 0) < T14_)) goto LA15_;
		result = shallowCopy__Dsjo9bte8vGxzhtcSrsTyiQ_3(n);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA19;
					i = i_2;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i]), subStride__Eo27jklJC4f01fawyLM2Vw(c, (*n)._kind_6.sons->data[i]));
					i_2 += ((NI) 1);
				} LA19: ;
			}
		}
	}
	goto LA1_;
	LA15_: ;
	{
		result = n;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI64, stride__qzhxkwLh9b1dUrty1QrNeVQ)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI64 result;
	result = (NI64)0;
	{
		NIM_BOOL T3_;
		NI s;
		T3_ = (NIM_BOOL)0;
		T3_ = isLocal__1EjP4hSli31mWSG19b8VOAw_2(n);
		if (!T3_) goto LA4_;
		s = lookupSlot__mQQqEPn8XV0sbu4TVfeZfQ(c, (*n)._kind_4.sym);
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = (((NI) 0) <= s);
			if (!(T8_)) goto LA9_;
			T8_ = !(((*c).locals->data[s].stride == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			LA9_: ;
			if (!T8_) goto LA10_;
			result = (*(*c).locals->data[s].stride)._kind_1.intVal;
		}
		LA10_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					NI64 T16_;
					if (!(i_2 < colontmp_)) goto LA15;
					i = i_2;
					T16_ = (NI64)0;
					T16_ = stride__qzhxkwLh9b1dUrty1QrNeVQ(c, (*n)._kind_6.sons->data[i]);
					result += T16_;
					i_2 += ((NI) 1);
				} LA15: ;
			}
		}
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkSlicesAreDisjoint__oEYSvTAgV5TtcIl6O6tf7A_2)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* c) {
	addLowerBoundAsFacts__oEYSvTAgV5TtcIl6O6tf7A(c);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** x;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** a;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** b;
		NI* id;
		NIM_BOOL* inLoop;
		NI i;
		NI L;
		NI T2_;
		x = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
		a = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
		b = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
		id = (NI*)0;
		inLoop = (NIM_BOOL*)0;
		i = ((NI) 0);
		T2_ = ((*c).slices ? (*c).slices->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				x = &(*c).slices->data[i].Field0;
				a = &(*c).slices->data[i].Field1;
				b = &(*c).slices->data[i].Field2;
				id = (&(*c).slices->data[i].Field3);
				inLoop = (&(*c).slices->data[i].Field4);
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T9_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T10_;
					if (!(*inLoop)) goto LA7_;
					T9_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T9_ = subStride__Eo27jklJC4f01fawyLM2Vw((&(*c)), (*a));
					T10_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T10_ = subStride__Eo27jklJC4f01fawyLM2Vw((&(*c)), (*b));
					overlap__Pk7bQd709cefQqdqSKch4Kg((&(*c).guards), (*(*c).graph).config, (*a), (*b), T9_, T10_);
				}
				LA7_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	{
		NI i_2;
		NI colontmp_;
		NI T12_;
		NI res;
		i_2 = (NI)0;
		colontmp_ = (NI)0;
		T12_ = (((*c).slices ? (*c).slices->Sup.len : 0)-1);
		colontmp_ = T12_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA14;
				i_2 = res;
				{
					NI j;
					NI colontmp__2;
					NI colontmp__3;
					NI T16_;
					NI res_2;
					j = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__3 = (NI)0;
					colontmp__2 = (NI)(i_2 + ((NI) 1));
					T16_ = (((*c).slices ? (*c).slices->Sup.len : 0)-1);
					colontmp__3 = T16_;
					res_2 = colontmp__2;
					{
						while (1) {
							tyTuple__SBroeDF0AeeG8DGttrMudQ x_2;
							tyTuple__SBroeDF0AeeG8DGttrMudQ y;
							if (!(res_2 <= colontmp__3)) goto LA18;
							j = res_2;
							nimZeroMem((void*)(&x_2), sizeof(tyTuple__SBroeDF0AeeG8DGttrMudQ));
							nimCopyMem((void*)(&x_2), (NIM_CONST void*)(&(*c).slices->data[i_2]), sizeof(x_2));
							nimZeroMem((void*)(&y), sizeof(tyTuple__SBroeDF0AeeG8DGttrMudQ));
							nimCopyMem((void*)(&y), (NIM_CONST void*)(&(*c).slices->data[j]), sizeof(y));
							{
								NIM_BOOL T21_;
								T21_ = (NIM_BOOL)0;
								T21_ = !((x_2.Field3 == y.Field3));
								if (!(T21_)) goto LA22_;
								T21_ = sameTree__Uv9a9aANFtV79cIvUP5jEeyVA(x_2.Field0, y.Field0);
								LA22_: ;
								if (!T21_) goto LA23_;
								{
									NIM_BOOL T27_;
									T27_ = (NIM_BOOL)0;
									T27_ = !(x_2.Field4);
									if (T27_) goto LA28_;
									T27_ = !(y.Field4);
									LA28_: ;
									if (!T27_) goto LA29_;
									overlap__Pk7bQd709cefQqdqSKch4Kg((&(*c).guards), (*(*c).graph).config, x_2.Field1, x_2.Field2, y.Field1, y.Field2);
								}
								goto LA25_;
								LA29_: ;
								{
									NI64 k;
									NI64 m;
									NIM_BOOL T32_;
									NI64 stride;
									NI64 T36_;
									NI64 T37_;
									k = simpleSlice__VGfXCY3TCP9cSnuVXj9a9a8nQ(x_2.Field1, x_2.Field2);
									m = simpleSlice__VGfXCY3TCP9cSnuVXj9a9a8nQ(y.Field1, y.Field2);
									T32_ = (NIM_BOOL)0;
									T32_ = (IL64(0) <= k);
									if (!(T32_)) goto LA33_;
									T32_ = (IL64(0) <= m);
									LA33_: ;
									if (!T32_) goto LA34_;
									overlap__Pk7bQd709cefQqdqSKch4Kg((&(*c).guards), (*(*c).graph).config, x_2.Field1, x_2.Field2, y.Field1, y.Field2);
									T36_ = (NI64)0;
									T36_ = stride__qzhxkwLh9b1dUrty1QrNeVQ((&(*c)), x_2.Field1);
									T37_ = (NI64)0;
									T37_ = stride__qzhxkwLh9b1dUrty1QrNeVQ((&(*c)), y.Field1);
									stride = ((T36_ <= T37_) ? T36_ : T37_);
									{
										NIM_BOOL T40_;
										T40_ = (NIM_BOOL)0;
										T40_ = (k < stride);
										if (!(T40_)) goto LA41_;
										T40_ = (m < stride);
										LA41_: ;
										if (!T40_) goto LA42_;
									}
									goto LA38_;
									LA42_: ;
									{
										tyArray__sMpvt1sOxOJ3LFGulnbeMQ T45_;
										NimStringDesc* T46_;
										nimZeroMem((void*)T45_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
										T45_[0] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(x_2.Field1, 0);
										T45_[1] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(x_2.Field2, 0);
										T45_[2] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(y.Field1, 0);
										T45_[3] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(y.Field2, 0);
										T46_ = (NimStringDesc*)0;
										T46_ = nsuFormatOpenArray(((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_30), T45_, 4);
										liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*x_2.Field0).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T46_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__Itl65swq3r8pqY8Wou1vYA_31, NIM_FALSE);
									}
									LA38_: ;
								}
								goto LA25_;
								LA34_: ;
								{
									tyArray__sMpvt1sOxOJ3LFGulnbeMQ T48_;
									NimStringDesc* T49_;
									nimZeroMem((void*)T48_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
									T48_[0] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(x_2.Field1, 0);
									T48_[1] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(x_2.Field2, 0);
									T48_[2] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(y.Field1, 0);
									T48_[3] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(y.Field2, 0);
									T49_ = (NimStringDesc*)0;
									T49_ = nsuFormatOpenArray(((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_30), T48_, 4);
									liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*x_2.Field0).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T49_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__Itl65swq3r8pqY8Wou1vYA_32, NIM_FALSE);
								}
								LA25_: ;
							}
							LA23_: ;
							res_2 += ((NI) 1);
						} LA18: ;
					}
				}
				res += ((NI) 1);
			} LA14: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, checkArgs__Cwo3r2QBfdI5juR3DQ1mAQ)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
}
N_LIB_PRIVATE N_NIMCALL(void, generateAliasChecks__qsgth9a5dt8cle6qTmFBAtQ)(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result) {
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformSlices__H1scsKXQAJ9cBTNEu0yVKsw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* op;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		LA4_: ;
		if (!T3_) goto LA5_;
		op = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		{
			NIM_BOOL T9_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* opSlice;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T13_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* slice;
			T9_ = (NIM_BOOL)0;
			T9_ = eqStrings((*(*op).name).s, ((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_7));
			if (!(T9_)) goto LA10_;
			T9_ = fromSystem__koLUZmQCBRKFmUFVrVvuPQastalgo(op);
			LA10_: ;
			if (!T9_) goto LA11_;
			result = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(n);
			T13_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			T13_ = createMagic__MzNJxZ0htpjW89c9b2wBN5rQ(g, ((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_38), ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 126));
			opSlice = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T13_);
			asgnRef((void**) (&(*opSlice).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg(g, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31)));
			add__P8dDSotTW25BkfbyspojGg(result, opSlice);
			add__P8dDSotTW25BkfbyspojGg(result, (*n)._kind_6.sons->data[((NI) 1)]);
			slice = skipStmtList__UPSW0jLTX5qJL51YMUAHgw_4((*n)._kind_6.sons->data[((NI) 2)]);
			add__P8dDSotTW25BkfbyspojGg(result, (*slice)._kind_6.sons->data[((NI) 1)]);
			add__P8dDSotTW25BkfbyspojGg(result, (*slice)._kind_6.sons->data[((NI) 2)]);
			goto BeforeRet_;
		}
		LA11_: ;
	}
	LA5_: ;
	{
		NI T16_;
		T16_ = (NI)0;
		T16_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
		if (!(((NI) 0) < T16_)) goto LA17_;
		result = shallowCopy__Dsjo9bte8vGxzhtcSrsTyiQ_3(n);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA21;
					i = i_2;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i]), transformSlices__H1scsKXQAJ9cBTNEu0yVKsw(g, (*n)._kind_6.sons->data[i]));
					i_2 += ((NI) 1);
				} LA21: ;
			}
		}
	}
	goto LA14_;
	LA17_: ;
	{
		result = n;
	}
	LA14_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformSpawnSons__E6FEP3eiSuBpDSuWg6Avkg_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* barrier) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = shallowCopy__Dsjo9bte8vGxzhtcSrsTyiQ_3(n);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				asgnRef((void**) (&(*result)._kind_6.sons->data[i]), transformSpawn__E6FEP3eiSuBpDSuWg6Avkg(g, owner, (*n)._kind_6.sons->data[i], barrier));
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformSpawn__E6FEP3eiSuBpDSuWg6Avkg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* barrier) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100):
	{
		result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
			it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
						if (!(i_2 < colontmp_)) goto LA5;
						i = i_2;
						it = (*n)._kind_6.sons->data[i];
						b = lastSon__UPSW0jLTX5qJL51YMUAHgw(it);
						{
							tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg T8_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* m;
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
							T8_ = (tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg)0;
							T8_ = getMagic__4W1ZJaFiusqlhViRx9cbM9bw(b);
							if (!(T8_ == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 194))) goto LA9_;
							{
								NI T13_;
								T13_ = (NI)0;
								T13_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
								if (!!((T13_ == ((NI) 3)))) goto LA14_;
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_36), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__Itl65swq3r8pqY8Wou1vYA_37, NIM_FALSE);
							}
							LA14_: ;
							m = transformSlices__H1scsKXQAJ9cBTNEu0yVKsw(g, b);
							{
								if (!(result == 0)) goto LA18_;
								result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
								add__P8dDSotTW25BkfbyspojGg(result, n);
							}
							LA18_: ;
							t = (*(*(*(*b)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)]).typ).sons->data[((NI) 0)];
							{
								tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw T22_;
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T25_;
								NI T26_;
								T22_ = (tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw)0;
								T22_ = spawnResult__115WOpmSjJFT089amuDIXdA(t, NIM_TRUE);
								if (!(T22_ == ((tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw) 2))) goto LA23_;
								T25_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								T25_ = wrapProcForSpawn__9cWXyScktPXvQmRC9aBs0ADw(g, owner, m, (*b).typ, barrier, (*it)._kind_6.sons->data[((NI) 0)]);
								add__P8dDSotTW25BkfbyspojGg(result, T25_);
								T26_ = (NI)0;
								T26_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
								asgnRef((void**) (&(*it)._kind_6.sons->data[(NI)(T26_ - ((NI) 1))]), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*it).info));
							}
							goto LA20_;
							LA23_: ;
							{
								NI T28_;
								T28_ = (NI)0;
								T28_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
								asgnRef((void**) (&(*it)._kind_6.sons->data[(NI)(T28_ - ((NI) 1))]), wrapProcForSpawn__9cWXyScktPXvQmRC9aBs0ADw(g, owner, m, (*b).typ, barrier, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
							}
							LA20_: ;
						}
						LA9_: ;
						i_2 += ((NI) 1);
					} LA5: ;
				}
			}
		}
		{
			if (!(result == 0)) goto LA31_;
			result = n;
		}
		LA31_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b_2;
		b_2 = (*n)._kind_6.sons->data[((NI) 1)];
		{
			NIM_BOOL T36_;
			tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg T37_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
			tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw T39_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* m_2;
			T36_ = (NIM_BOOL)0;
			T37_ = (tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg)0;
			T37_ = getMagic__4W1ZJaFiusqlhViRx9cbM9bw(b_2);
			T36_ = (T37_ == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 194));
			if (!(T36_)) goto LA38_;
			t_2 = (*(*(*(*b_2)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)]).typ).sons->data[((NI) 0)];
			T39_ = (tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw)0;
			T39_ = spawnResult__115WOpmSjJFT089amuDIXdA(t_2, NIM_TRUE);
			T36_ = (T39_ == ((tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw) 2));
			LA38_: ;
			if (!T36_) goto LA40_;
			m_2 = transformSlices__H1scsKXQAJ9cBTNEu0yVKsw(g, b_2);
			result = wrapProcForSpawn__9cWXyScktPXvQmRC9aBs0ADw(g, owner, m_2, (*b_2).typ, barrier, (*n)._kind_6.sons->data[((NI) 0)]);
			goto BeforeRet_;
		}
		LA40_: ;
		result = transformSpawnSons__E6FEP3eiSuBpDSuWg6Avkg_2(g, owner, n, barrier);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		{
			tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg T45_;
			T45_ = (tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg)0;
			T45_ = getMagic__4W1ZJaFiusqlhViRx9cbM9bw(n);
			if (!(T45_ == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 194))) goto LA46_;
			result = transformSlices__H1scsKXQAJ9cBTNEu0yVKsw(g, n);
			result = wrapProcForSpawn__9cWXyScktPXvQmRC9aBs0ADw(g, owner, result, (*n).typ, barrier, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			goto BeforeRet_;
		}
		LA46_: ;
		result = transformSpawnSons__E6FEP3eiSuBpDSuWg6Avkg_2(g, owner, n, barrier);
	}
	break;
	default:
	{
		{
			NI T51_;
			T51_ = (NI)0;
			T51_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			if (!(((NI) 0) < T51_)) goto LA52_;
			result = transformSpawnSons__E6FEP3eiSuBpDSuWg6Avkg_2(g, owner, n, barrier);
		}
		goto LA49_;
		LA52_: ;
		{
			result = n;
		}
		LA49_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, liftParallel__ndOOzgg7N9cEw3E9bRfkcIDw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg a;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varSection;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* temp;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T5_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T6_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tempNode;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* barrier;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T7_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T8_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T9_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nimZeroMem((void*)(&a), sizeof(tyObject_AnalysisCtx__GAXrqb9cmHjKTVCb6BokzLg));
	initAnalysisCtx__GoSHD4Mq66yV2bANMNqkiA(g, (&a));
	body = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
	analyse__PaRoa8NLdkCWN1FglnKPWw((&a), body);
	{
		if (!(a.spawns == ((NI) 0))) goto LA3_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_23), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__Itl65swq3r8pqY8Wou1vYA_24, NIM_FALSE);
	}
	LA3_: ;
	checkSlicesAreDisjoint__oEYSvTAgV5TtcIl6O6tf7A_2((&a));
	checkArgs__Cwo3r2QBfdI5juR3DQ1mAQ((&a), body);
	varSection = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99), (*n).info);
	T5_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T5_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*g).cache, ((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_33));
	temp = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 5), T5_, owner, (*n).info, 0);
	T6_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T6_ = getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA(g, ((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_34));
	asgnRef((void**) (&(*temp).typ), (*T6_).typ);
	(*temp).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 2)) & 63);
	tempNode = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(temp);
	addVar__qOCBdprWtK4hxer73SEdQA(varSection, tempNode);
	barrier = genAddrOf__llCeDV6q0X9bzDY9agj6OpdQ(tempNode, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21));
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
	generateAliasChecks__qsgth9a5dt8cle6qTmFBAtQ((&a), result);
	add__P8dDSotTW25BkfbyspojGg(result, varSection);
	T7_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T7_ = callCodegenProc__6cD4vACMYqPEkcqC9cypTrw(g, ((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_35), (*barrier).info, barrier, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	add__P8dDSotTW25BkfbyspojGg(result, T7_);
	T8_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T8_ = transformSpawn__E6FEP3eiSuBpDSuWg6Avkg(g, owner, body, barrier);
	add__P8dDSotTW25BkfbyspojGg(result, T8_);
	T9_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T9_ = callCodegenProc__6cD4vACMYqPEkcqC9cypTrw(g, ((NimStringDesc*) &TM__Itl65swq3r8pqY8Wou1vYA_39), (*barrier).info, barrier, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	add__P8dDSotTW25BkfbyspojGg(result, T9_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, compiler_semparallelDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__Itl65swq3r8pqY8Wou1vYA_2_7[7];
static TNimNode* TM__Itl65swq3r8pqY8Wou1vYA_3_2[2];
NI TM__Itl65swq3r8pqY8Wou1vYA_5;
static char* NIM_CONST TM__Itl65swq3r8pqY8Wou1vYA_4[2] = {
"ascending", 
"descending"};
static TNimNode* TM__Itl65swq3r8pqY8Wou1vYA_17_5[5];
static TNimNode TM__Itl65swq3r8pqY8Wou1vYA_0[17];

/* section: NIM_merge_TYPE_INIT3 */
NTI__PyZQX2tcVOc67gX80PLPxA_.size = sizeof(tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA);
NTI__PyZQX2tcVOc67gX80PLPxA_.align = NIM_ALIGNOF(tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA);
NTI__PyZQX2tcVOc67gX80PLPxA_.kind = 18;
NTI__PyZQX2tcVOc67gX80PLPxA_.base = 0;
NTI__PyZQX2tcVOc67gX80PLPxA_.flags = 2;
TM__Itl65swq3r8pqY8Wou1vYA_2_7[0] = &TM__Itl65swq3r8pqY8Wou1vYA_0[1];
TM__Itl65swq3r8pqY8Wou1vYA_0[1].kind = 1;
TM__Itl65swq3r8pqY8Wou1vYA_0[1].offset = offsetof(tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA, v);
TM__Itl65swq3r8pqY8Wou1vYA_0[1].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__Itl65swq3r8pqY8Wou1vYA_0[1].name = "v";
TM__Itl65swq3r8pqY8Wou1vYA_2_7[1] = &TM__Itl65swq3r8pqY8Wou1vYA_0[2];
TM__Itl65swq3r8pqY8Wou1vYA_0[2].kind = 1;
TM__Itl65swq3r8pqY8Wou1vYA_0[2].offset = offsetof(tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA, alias);
TM__Itl65swq3r8pqY8Wou1vYA_0[2].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__Itl65swq3r8pqY8Wou1vYA_0[2].name = "alias";
TM__Itl65swq3r8pqY8Wou1vYA_2_7[2] = &TM__Itl65swq3r8pqY8Wou1vYA_0[3];
TM__Itl65swq3r8pqY8Wou1vYA_0[3].kind = 1;
TM__Itl65swq3r8pqY8Wou1vYA_0[3].offset = offsetof(tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA, lower);
TM__Itl65swq3r8pqY8Wou1vYA_0[3].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__Itl65swq3r8pqY8Wou1vYA_0[3].name = "lower";
TM__Itl65swq3r8pqY8Wou1vYA_2_7[3] = &TM__Itl65swq3r8pqY8Wou1vYA_0[4];
TM__Itl65swq3r8pqY8Wou1vYA_0[4].kind = 1;
TM__Itl65swq3r8pqY8Wou1vYA_0[4].offset = offsetof(tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA, upper);
TM__Itl65swq3r8pqY8Wou1vYA_0[4].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__Itl65swq3r8pqY8Wou1vYA_0[4].name = "upper";
TM__Itl65swq3r8pqY8Wou1vYA_2_7[4] = &TM__Itl65swq3r8pqY8Wou1vYA_0[5];
TM__Itl65swq3r8pqY8Wou1vYA_0[5].kind = 1;
TM__Itl65swq3r8pqY8Wou1vYA_0[5].offset = offsetof(tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA, stride);
TM__Itl65swq3r8pqY8Wou1vYA_0[5].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__Itl65swq3r8pqY8Wou1vYA_0[5].name = "stride";
TM__Itl65swq3r8pqY8Wou1vYA_2_7[5] = &TM__Itl65swq3r8pqY8Wou1vYA_0[6];
NTI__ogNRjad5Q2m49bwMa6pnI3w_.size = sizeof(tyEnum_TDirection__ogNRjad5Q2m49bwMa6pnI3w);
NTI__ogNRjad5Q2m49bwMa6pnI3w_.align = NIM_ALIGNOF(tyEnum_TDirection__ogNRjad5Q2m49bwMa6pnI3w);
NTI__ogNRjad5Q2m49bwMa6pnI3w_.kind = 14;
NTI__ogNRjad5Q2m49bwMa6pnI3w_.base = 0;
NTI__ogNRjad5Q2m49bwMa6pnI3w_.flags = 3;
for (TM__Itl65swq3r8pqY8Wou1vYA_5 = 0; TM__Itl65swq3r8pqY8Wou1vYA_5 < 2; TM__Itl65swq3r8pqY8Wou1vYA_5++) {
TM__Itl65swq3r8pqY8Wou1vYA_0[TM__Itl65swq3r8pqY8Wou1vYA_5+7].kind = 1;
TM__Itl65swq3r8pqY8Wou1vYA_0[TM__Itl65swq3r8pqY8Wou1vYA_5+7].offset = TM__Itl65swq3r8pqY8Wou1vYA_5;
TM__Itl65swq3r8pqY8Wou1vYA_0[TM__Itl65swq3r8pqY8Wou1vYA_5+7].name = TM__Itl65swq3r8pqY8Wou1vYA_4[TM__Itl65swq3r8pqY8Wou1vYA_5];
TM__Itl65swq3r8pqY8Wou1vYA_3_2[TM__Itl65swq3r8pqY8Wou1vYA_5] = &TM__Itl65swq3r8pqY8Wou1vYA_0[TM__Itl65swq3r8pqY8Wou1vYA_5+7];
}
TM__Itl65swq3r8pqY8Wou1vYA_0[9].len = 2; TM__Itl65swq3r8pqY8Wou1vYA_0[9].kind = 2; TM__Itl65swq3r8pqY8Wou1vYA_0[9].sons = &TM__Itl65swq3r8pqY8Wou1vYA_3_2[0];
NTI__ogNRjad5Q2m49bwMa6pnI3w_.node = &TM__Itl65swq3r8pqY8Wou1vYA_0[9];
TM__Itl65swq3r8pqY8Wou1vYA_0[6].kind = 1;
TM__Itl65swq3r8pqY8Wou1vYA_0[6].offset = offsetof(tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA, dir);
TM__Itl65swq3r8pqY8Wou1vYA_0[6].typ = (&NTI__ogNRjad5Q2m49bwMa6pnI3w_);
TM__Itl65swq3r8pqY8Wou1vYA_0[6].name = "dir";
TM__Itl65swq3r8pqY8Wou1vYA_2_7[6] = &TM__Itl65swq3r8pqY8Wou1vYA_0[10];
TM__Itl65swq3r8pqY8Wou1vYA_0[10].kind = 1;
TM__Itl65swq3r8pqY8Wou1vYA_0[10].offset = offsetof(tyObject_MonotonicVar__PyZQX2tcVOc67gX80PLPxA, blacklisted);
TM__Itl65swq3r8pqY8Wou1vYA_0[10].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__Itl65swq3r8pqY8Wou1vYA_0[10].name = "blacklisted";
TM__Itl65swq3r8pqY8Wou1vYA_0[0].len = 7; TM__Itl65swq3r8pqY8Wou1vYA_0[0].kind = 2; TM__Itl65swq3r8pqY8Wou1vYA_0[0].sons = &TM__Itl65swq3r8pqY8Wou1vYA_2_7[0];
NTI__PyZQX2tcVOc67gX80PLPxA_.node = &TM__Itl65swq3r8pqY8Wou1vYA_0[0];
NTI__JsYE17s5Dad5mZDxLHKgaw_.size = sizeof(tySequence__JsYE17s5Dad5mZDxLHKgaw*);
NTI__JsYE17s5Dad5mZDxLHKgaw_.align = NIM_ALIGNOF(tySequence__JsYE17s5Dad5mZDxLHKgaw*);
NTI__JsYE17s5Dad5mZDxLHKgaw_.kind = 24;
NTI__JsYE17s5Dad5mZDxLHKgaw_.base = (&NTI__PyZQX2tcVOc67gX80PLPxA_);
NTI__JsYE17s5Dad5mZDxLHKgaw_.flags = 2;
NTI__JsYE17s5Dad5mZDxLHKgaw_.marker = Marker_tySequence__JsYE17s5Dad5mZDxLHKgaw;
NTI__SBroeDF0AeeG8DGttrMudQ_.size = sizeof(tyTuple__SBroeDF0AeeG8DGttrMudQ);
NTI__SBroeDF0AeeG8DGttrMudQ_.align = NIM_ALIGNOF(tyTuple__SBroeDF0AeeG8DGttrMudQ);
NTI__SBroeDF0AeeG8DGttrMudQ_.kind = 18;
NTI__SBroeDF0AeeG8DGttrMudQ_.base = 0;
NTI__SBroeDF0AeeG8DGttrMudQ_.flags = 2;
TM__Itl65swq3r8pqY8Wou1vYA_17_5[0] = &TM__Itl65swq3r8pqY8Wou1vYA_0[12];
TM__Itl65swq3r8pqY8Wou1vYA_0[12].kind = 1;
TM__Itl65swq3r8pqY8Wou1vYA_0[12].offset = offsetof(tyTuple__SBroeDF0AeeG8DGttrMudQ, Field0);
TM__Itl65swq3r8pqY8Wou1vYA_0[12].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__Itl65swq3r8pqY8Wou1vYA_0[12].name = "Field0";
TM__Itl65swq3r8pqY8Wou1vYA_17_5[1] = &TM__Itl65swq3r8pqY8Wou1vYA_0[13];
TM__Itl65swq3r8pqY8Wou1vYA_0[13].kind = 1;
TM__Itl65swq3r8pqY8Wou1vYA_0[13].offset = offsetof(tyTuple__SBroeDF0AeeG8DGttrMudQ, Field1);
TM__Itl65swq3r8pqY8Wou1vYA_0[13].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__Itl65swq3r8pqY8Wou1vYA_0[13].name = "Field1";
TM__Itl65swq3r8pqY8Wou1vYA_17_5[2] = &TM__Itl65swq3r8pqY8Wou1vYA_0[14];
TM__Itl65swq3r8pqY8Wou1vYA_0[14].kind = 1;
TM__Itl65swq3r8pqY8Wou1vYA_0[14].offset = offsetof(tyTuple__SBroeDF0AeeG8DGttrMudQ, Field2);
TM__Itl65swq3r8pqY8Wou1vYA_0[14].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__Itl65swq3r8pqY8Wou1vYA_0[14].name = "Field2";
TM__Itl65swq3r8pqY8Wou1vYA_17_5[3] = &TM__Itl65swq3r8pqY8Wou1vYA_0[15];
TM__Itl65swq3r8pqY8Wou1vYA_0[15].kind = 1;
TM__Itl65swq3r8pqY8Wou1vYA_0[15].offset = offsetof(tyTuple__SBroeDF0AeeG8DGttrMudQ, Field3);
TM__Itl65swq3r8pqY8Wou1vYA_0[15].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__Itl65swq3r8pqY8Wou1vYA_0[15].name = "Field3";
TM__Itl65swq3r8pqY8Wou1vYA_17_5[4] = &TM__Itl65swq3r8pqY8Wou1vYA_0[16];
TM__Itl65swq3r8pqY8Wou1vYA_0[16].kind = 1;
TM__Itl65swq3r8pqY8Wou1vYA_0[16].offset = offsetof(tyTuple__SBroeDF0AeeG8DGttrMudQ, Field4);
TM__Itl65swq3r8pqY8Wou1vYA_0[16].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__Itl65swq3r8pqY8Wou1vYA_0[16].name = "Field4";
TM__Itl65swq3r8pqY8Wou1vYA_0[11].len = 5; TM__Itl65swq3r8pqY8Wou1vYA_0[11].kind = 2; TM__Itl65swq3r8pqY8Wou1vYA_0[11].sons = &TM__Itl65swq3r8pqY8Wou1vYA_17_5[0];
NTI__SBroeDF0AeeG8DGttrMudQ_.node = &TM__Itl65swq3r8pqY8Wou1vYA_0[11];
NTI__6lRdzb9aFAlo79bGaEawph6g_.size = sizeof(tySequence__6lRdzb9aFAlo79bGaEawph6g*);
NTI__6lRdzb9aFAlo79bGaEawph6g_.align = NIM_ALIGNOF(tySequence__6lRdzb9aFAlo79bGaEawph6g*);
NTI__6lRdzb9aFAlo79bGaEawph6g_.kind = 24;
NTI__6lRdzb9aFAlo79bGaEawph6g_.base = (&NTI__SBroeDF0AeeG8DGttrMudQ_);
NTI__6lRdzb9aFAlo79bGaEawph6g_.flags = 2;
NTI__6lRdzb9aFAlo79bGaEawph6g_.marker = Marker_tySequence__6lRdzb9aFAlo79bGaEawph6g;
}

